#ifndef __RANDOM_H__
#define __RANDOM_H__

// Define a quick and dirty generator
#define RANDMUL 1664525L
#define RANDADD 1013904223L

#define RAND(seed) ((seed = seed * RANDMUL + RANDADD) & 0xFFFFFFFF)

class Random
// Implements the minimal random number generator of Park
// and Miller with Bays-Durham shuffle and added safe guards
   {
   protected:
      // values for "minimal random values"
      long  seed;
      long  last;
      long  * shuffler;

      // values for "binary random values"
      long bseed;

      // and for normal deviates
      int      normSaved;
      double   normStore;

   public:
      Random(long s = 0x7654321);
      ~Random()
         {
         delete [] shuffler;
         }


      int    Binary();     // Next bit in series of 0s and 1s
      double Next();       // Next value in series, between 0 and 1
      double Normal();     // Random number from N(0,1)
      void   Reset(long s);

      operator double()    // Random number between 0 and 1
         { return Next(); }
   };

extern Random globalRandom;

#endif
 
 
 
 
 
 
