#ifndef __KAC_H__
#define __KAC_H__

#include "Pedigree.h"
#include "MathMatrix.h"
#include "MathGold.h"

class FamilyAnalysis;

class KAC : public ScalarMinimizer
   {
   public:
      int affectionCount, familyCount, positionCount;
      Vector * min;         // min[affection][family]
      Vector * max;         // max[affection][family]
      Matrix * scores;      // scores[affection][family][position]
      StringArray & labels; // labels for analysis positions
      StringArray pheno;    // labels for phenotypes

      KAC(Pedigree & ped, StringArray & labels);
      ~KAC();

      void LabelPhenotypes(bool all, bool pairs, bool qtl, bool dev);
      void Prepare(int affections, int families);
      void Set(int affection, int family, double lo, double hi, Vector & z);

      //void Analyse(MerlinPDF & pdf);
      void Analyse(Vector & save_results);
      void AnalyseAffection(int curr_affection, Vector & chis, Vector & deltas, Vector & zmeans, bool write_results);

      void SkipFamily(int serial);

      // These functions manage [merlin.lod] files for storing individual
      // scores for each family
      void OpenPerFamilyFiles();
      void ClosePerFamilyFiles();
      void OutputPerFamilyScores(int affection, int position, double delta);

      void SelectChromosome(int chr);
      void SelectChromosomeX();

   private:
      virtual double f(double delta);

      int    currentAffection, currentPosition;
      String chromosome;
      double minimum, range;

      double MakeDelta(double value);
      void   OutputScores(const char * pos, double z, double d, double chisq);

      // Output file for individual scores
      FILE * perfamily;

      // Reference to original pedigree
      Pedigree & ped;
   };

#endif
 
 
 
 
