#include "PseudoSimulator.h"
#include "Parameters.h"
#include "Pedigree.h"
#include "Error.h"
#include "StringBasics.h"
#include "PDFhistogram.h"
#include "Random.h"

#include <stdio.h>

void ReadParameters(int argc, char * argv[]);

int random_seed = int(time(NULL));

int main(int argc, char * argv[])
   {
   #ifndef PSEUDOVERSION
      printf("PseudoSimulator\n(c) 2003-2005 Jan Wigginton, 2003-2005 Goncalo Abecasis\n\n");
   #else
      printf("PseudoSimulator - " PSEUDOVERSION "\n"
             "(c) 2003-2005 Jan Wigginton, 2003-2005 Goncalo Abecasis\n\n");
   #endif

   PseudoHypotheses::hypFileName = PseudoSimulator::filePrefix + ".hyp";
   PseudoDataInfo::fileFileName  = PseudoSimulator::filePrefix +".list";

   ReadParameters(argc, argv);

   PseudoSimulator::hitsFileName   = PseudoSimulator::filePrefix + ".hits";
   PseudoSimulator::maxChrFileName    = PseudoSimulator::filePrefix + ".max";
   PseudoSimulator::maxGenomeFileName = PseudoSimulator::filePrefix + ".simmax";
   PseudoVariance::weightsFileName = PseudoSimulator::filePrefix + ".weights";
   PseudoVariance::repsFileName = PseudoSimulator::filePrefix + ".reps";
   PseudoPDF::pdfFileName = PseudoSimulator::filePrefix + ".pdf";

   PseudoSimulator sim;
   sim.TestHypotheses();
   }

BEGIN_LONG_PARAMETERS(longParameters)
   LONG_PARAMETER_GROUP("Analysis Options")
      EXCLUSIVE_PARAMETER("balanced", &PseudoSimulator::evenSampling)
      EXCLUSIVE_PARAMETER("random", &PseudoSimulator::randomSampling)
      LONG_INTPARAMETER("chrMax", &PseudoDataInfo::maxNChr)
   LONG_PARAMETER_GROUP("Optional Summaries")
      LONG_PARAMETER("peaks", &PseudoSimulator::maxByChromosome)
      LONG_PARAMETER("simpeaks", &PseudoSimulator::maxByGenome)
      LONG_PARAMETER("hits", &PseudoSimulator::hitsByGenome)
   LONG_PARAMETER_GROUP("Weight Summaries")
      LONG_PARAMETER("reps", &PseudoSimulator::repSummary)
      LONG_PARAMETER("weights", &PseudoSimulator::weightSummary)
   LONG_PARAMETER_GROUP("Output Options")
      LONG_PARAMETER("quiet", &PseudoSimulator::quietOutput)
      LONG_STRINGPARAMETER("prefix", &PseudoSimulator::filePrefix)
      LONG_PARAMETER("pdf", &PseudoSimulator::writePDF)
   LONG_PARAMETER_GROUP("Resource Usage")
      LONG_INTPARAMETER("megabytes", &PseudoSimulator::maxMegabytes)
      LONG_INTPARAMETER("diskSpace", &PseudoSimulator::maxDiskSpace)
      LONG_INTPARAMETER("thinData", &PseudoDataInfo::gridPoints)
END_LONG_PARAMETERS();

void ReadParameters(int argc, char * argv[])
   {
   ParameterList pl;

   pl.Add(new StringParameter('l', "List of replicates", PseudoDataInfo::fileFileName));
   pl.Add(new IntParameter('n', "Replicates to generate", PseudoSimulator::nPseudoSimulations));
   pl.Add(new StringParameter('h', "Hypothesis Table", PseudoHypotheses::hypFileName));
   pl.Add(new IntParameter('r', "Random Seed", random_seed));
   pl.Add(new LongParameters("Additional Options", longParameters));

   pl.Read(argc, argv);
   pl.Status();

   globalRandom.Reset(random_seed);
   }


 
 
 
