// PseudoDataInfo.h
// Written by Jan Wigginton

#ifndef _PSEUDODATAINFO_H_
#define _PSEUDODATAINFO_H_

#include "StringMap.h"
#include "StringArray.h"
#include "IntArray.h"

class PseudoDataInfo
   {
   public:

      friend class PseudoSimulator;
      friend class PseudoZScorePool;

      PseudoDataInfo();
      ~PseudoDataInfo();

      // Total number of analysis positions on all chromosomes, number of skipped positions
      int nAllPositions, nSkippedPositions;

      // Number of chromosomes
      int nChromosomes;

      // Number of families
      int nFamilies;

      // Number of z-score pools
      int nPools;

      // Number of affections
      int nAffections;

      //Number of hypotheses
      int nHypotheses;

      // Indicator for input file format: T -> lod file format, F -> z-score format
      bool useLodFiles;

      // Name of input file with list of names of files containing z-score pools
      static String fileFileName;

      // Maximum chromosome number allowed
      static int maxNChr;


      // Overall affections in the dataset
      StringIntMap possibleAffectionLookup;

      // Searchable array of affections to be analyzed
      StringIntMap affectionLookup;

      // Searchable array of all analysis positions
      StringIntMap positionLookup;

      // Searchable array of all skipped positions
      StringIntMap skippedLookup;

        // Searchable array of family names
      StringIntMap familyLookup;

      // Searchable StringIntMap of chromosome names
      StringIntMap chromosomeLookup;

      // Array of names of chromosomes to be analysed
      // NOTE: chromosomes are analysed and reported in the order they are read in
      StringArray chromosomeNames;

      // Names for files containing z-score pools
      StringArray filesToRead;

      // Sampling grid frequency (gridPoints = 2 => every other point sampled)
      static int gridPoints;

      // Array of marker set indices (one for each chromosome) in overall array of markers
      IntArray * markerSets;

      // Arrays of position labels (one array per chromosome)
      StringArray * analysisPositions;

      // Selectable String variables to be used for searching, printing
      String workingAffectionName, currAffectionName;

      // Updates workingAffection, currentAffection with affection name/score type
      void SelectAffectionName(const char * affection_name, int score_type);

      // Returns index of score type corresponding to score label
      int  GetScoreType(const char * score_label);


      // Initializes basic data parameters and indices for simulation
      void Load();

   private:

      // Skipping analysis positions?
      bool gridOn;

      // Is input file type determined already?
      bool fileTypeKnown;

      // Determines type of file to be used for data input
      bool UseLodFiles();

      // Verifies that at least one family, chromosome and affection are present in the first z-score file
      void CheckForData();

      // Reads list of files to be loaded
      int  ReadFileNames();

      // Reads first data file for setup information (lod or zscore)
      void SetupUsingLodFile(const char * first_file);
      void SetupUsingZscoreFile(const char * first_file);

      void   AllocatePositionArrays();
      void   FreePositionArrays();
      double EstimateArrayMemory();

      // Constructs markerSets (indices for locating chromosome markers in overall data matrix)
      void MakeMarkerSets();


};


#endif

 
 
 
