// PseudoHypotheses.h
// Written by Jan Wigginton

#ifndef _PSEUDOHYPOTHESES_H_
#define _PSEUDOHYPOTHESES_H_

#include "StringMap.h"
#include "StringArray.h"
#include "MathVector.h"
#include "IntArray.h"

class PseudoDataInfo;

class PseudoHypotheses
   {
   friend class PseudoSimulator;
   friend class PseudoVariance;

   public:

      PseudoHypotheses(PseudoDataInfo & i);
      ~PseudoHypotheses();

      // Data file describing hypotheses to test
      static String hypFileName;

      // Lods to test - lodsToTest[hyp] = lod test value for hypothesis hyp
      Vector lodsToTest;

      // Ranks to test - ranksToTest[hyp] = test rank for hypothesis hyp
      IntArray ranksToTest;

      // Matrix of indicators for each hypothesis
      // affectionGroups[i][j] = 1 implies that affection j is a component of hypothesis i
      IntArray * affectionGroups;

      // Hypothesis descriptions used for table and p-value output
      StringArray descriptions;

      // Labels/identifiers for hypotheses
      StringArray labels;

      // Alias for number of hypotheses (= info.nHypotheses)
      int & nHypotheses;

      // Alias for number of affections (= info.nAffections)
      int & nAffections;

      //Indicator array for grouping hypotheses that differ only by rank or lod value to test
      IntArray groupMembership;

      // Number of unique outcomes of interest
      int nGroups;

      // Array of labels listing hypotheses in each unique-outcome group
      StringArray groupLabels;

      // Read hypotheses from hypFile
      void ReadHypotheses();

      // Constructs string describing hypothesis
      String  GetDescriptiveString(int hyp, int indent, int line_len = 35);

   private:

      // Alias used to reference data information structure
      PseudoDataInfo & info;

      int  maxAffLabelLen, maxHypLabelLen;

      void RecordHypothesis(StringArray & tokens, StringMap & affections);
      void RecordShortHandHypothesis(StringMap & affections);
      void RecordLongHandHypothesis(StringArray & tokens, StringMap & affections);

      void RecordNextAffection(const char * aff_label, int score_type, StringMap & affections);
      void RecordAllAffections(StringMap & affections);
      void RecordAffection(const char * working_affection_name, StringMap & affections);

      void UpdateHypothesisDescriptions(const char * aff, const char * score);
      void PrintHypothesisDescription(FILE * file, int hyp);

      void RecordHypothesisGroups();
      void BuildGroupLabels(int first_line_len, int max_line_len);

      void AllocateAffectionGroups(const StringMap & affections);
      void FreeAffectionGroups();

      double  EstimateArrayMemory();
   };


#endif


 
 
 
