// PseudoPDF.h
// Written by Jan Wigginton

#ifndef _PSEUDOPDF_H_
#define _PSEUDOPDF_H_

#define PSEUDO_N_PDF_BINS 300

#include "MathMatrix.h"
#include "IntArray.h"
#include "PDF.h"
#include "Constant.h"
#include "StringArray.h"

#include "PseudoDataInfo.h"
#include "PseudoHypotheses.h"

class PseudoPDF
   {
   friend class PseudoSimulator;

   PseudoPDF(PseudoHypotheses & h, PseudoDataInfo & i);
   ~PseudoPDF();

   public:

      // Name of file for graphing results
      static String pdfFileName;

      // Array of bin limits used to accumulate counts for graphing
      static double lowerBinLimits[PSEUDO_N_PDF_BINS];

   private:

      PDF  pdf;

      // Alias for hypothesis info structure
      PseudoHypotheses & hypInfo;

      // Alias for data info structure
      PseudoDataInfo   & info;

     // Cumulative counts for genomewide max lods in bin increments of 0.1 between -20.0 and 20.0
      Matrix * genomeMaxCts;

      // Cumulative counts for chromosome specific max lods in bin increments of 0.1 (-20.0 to 20.0)
      Matrix * chrMaxCts;

      // Number of bins tracked
      int nPDFBins;

      // Counts of hits per genome by lod score cutoff
      Matrix logThreshHoldCounts;

      // List of categories considered
      Vector logThreshHolds;

      // Alias to simplify notation (= info.nHypotheses)
      int & nHypotheses;

      // Alias for info.nChromosomes
      int & nChromosomes;

      //Maximum, minimum simulated lod over all pseudoreplicate scans
      Vector maxLod, minLod;

      void GraphResults(IntArray * significant_counts);

      void DrawSignificanceHistogram(int hyp, IntArray & significant_counts);
      void DrawMaxLodDistribution(int hyp);
      void DrawMaxLodGraph(int hyp, const char * label, Matrix & lods, double bar_width, bool green = false);
      void DrawLogHits();

      void DetermineBins(Matrix & new_lods, const Matrix & old_lods, int row,
           double & bar_width, double max = _NAN_, double min = _NAN_);
      void UpdateCounts(Matrix * max_chromsome_lods, int buffer_size);
      void UpdateBins(Matrix & max_chromsome_lods, int hyp, int buffer_size);
      void CountHitsByThreshHold(Matrix & max_chromosome_lods, int hyp, int buffer_size);

      void AllocateResultArrays();
      void FreeResultArrays();

      double EstimateArrayMemory();
   };

#endif
 
 
 
