// PseudoVariance.h:
// Written by:  Jan Wigginton
// Last update: 09/08/05

#ifndef _PSEUDOVARIANCE_H_
#define _PSEUDOVARIANCE_H_

#include "IntArray.h"
#include "StringBasics.h"
#include "PseudoHypotheses.h"
#include "PseudoDataInfo.h"
#include "MathMatrix.h"

class PseudoVariance
   {
   friend class PseudoSimulator;

   public:

      PseudoVariance(PseudoHypotheses & h, PseudoDataInfo & i);
      ~PseudoVariance();

      //familyWeight[hyp][fam][chr] = variance weight for family fam on chromosome chr
      Matrix * familyWeights;

      //Name of output file for summary information on family weight distribution
      static String weightsFileName;

      //Name of output file for detailed information on family weight distribution
      static String repsFileName;

      double GetEstimatedVariance(int hyp, double p_hat);
      void   PrintFamilyWeights();

   private:

      // Alias for structures containing data/hypothesis information
      PseudoDataInfo & info;
      PseudoHypotheses & hypInfo;

      // Counts used to calculate variance - times chosen/positive by fam, chr and replicate
      IntArray ** repCounts, *** repPosCounts;

      // File for output of short summary containing family-specific weights by chromosome
      FILE * weightsFile;

      // File for output of  long summary containing roportion + outcomes by rep,
      // hypothesis, chromosome and family
      FILE * repsFile;

      // Indicator that weight family specific variance weights have already been calculated
      bool weightsEstimated;

      // Aliases to items in PseudoDataInfo structure -- used to simplify notation
      int & nPools, & nFamilies, & nChromosomes, & nHypotheses;

      // Used to estimate output file size
      String weightsFormat, repsFormat;
      
      void OpenSummaryFiles(bool weights, bool reps);
      void CloseSummaryFiles();

      void PrintFamilyRepSummaries();
      void PrintFamilyRepSummary(int hyp, int chr);
      void PrintFamilyWeights(int chr, int hyp);
      void PrintHypothesisHeader(int hyp, const char * summary_label);

      void SummarizeWeights();
      
      void SummarizeWeightsByChromosome(int hyp);
      void GetExtremeFamilies(int hyp, bool get_max, Vector & weights, IntArray & families, Vector & averages);
      void SummarizeWeightsByFamily(int hyp);
      void GetExtremeChromosomes(int hyp, bool get_max, Vector & weights, IntArray & chromosomes, Vector & averages);
 
      void EstimateFamilyWeights();

      void AllocateResultArrays();
      void FreeResultArrays();

      double EstimateArrayMemory();
   };

#endif

 
 
 
 
