// PseudoZScorePool.h
// Written by Jan Wigginton

#ifndef _PSEUDOZSCOREPOOL_H_
#define _PSEUDOZSCOREPOOL_H_

#include "MathMatrix.h"
#include "StringArray.h"
#include "IntArray.h"

class PseudoDataInfo;

class PseudoZScorePool
   {
   friend class PseudoSimulator;

   public:

       PseudoZScorePool(PseudoDataInfo & data_info);
      ~PseudoZScorePool();

      void   LoadData();
      double    EstimateArrayMemory();

   private:

      // Alias for data information structure
      PseudoDataInfo & info;

      // Alias for number of z-score pools (= info.nPools)
      int & nPools;

      // Scores by affection, position, family, and replicate
      Matrix ** affectionScores;

      // Mins by affection, chromosome, family, replicate
      Matrix ** affectionMins;

      // Maxs by affection, chromosomes, family, replicate
      Matrix ** affectionMaxs;


      void ReadRawLodData();
      void ReadRawLodFile(int sim);

      void ReadRawZScoreData();
      void ReadRawZScoreFile(int sim);

      int  ReadZAffectionLine(StringArray & tokens);
      int  ReadZChromosomeLine(StringArray & tokens, String & curr_chromosome, int sim);
      void ReadZFamilyLine(StringArray & tokens, StringArray & position_line,
            IntArray & position_indices, int aff_index, int chr_index, int sim);

      void DeterminePositionIndices(StringArray & position_line, IntArray & position_indices,
            String & curr_chromosome, int sim);

      void AllocateInputArrays();
      void FreeInputArrays();


   };

#endif
 
 
 
